@@ -431,6 +431,7 @@ update.km <- function(object,
         if (is.null(kmcontrol$optim.method)) kmcontrol$optim.method <- object@optim.method 
         if (length(kmcontrol$optim.method) == 0) kmcontrol$optim.method <- "BFGS"
         if (is.null(kmcontrol$control)) kmcontrol$control <- object@control
+	if (is.null(kmcontrol$multistart)) kmcontrol$multistart <- object@control$multistart
         if(length(object@gr) == 0) object@gr <- TRUE
         knots <- NULL; if(TheClass == "covScaling") knots <- object@covariance@knots
         
@@ -440,7 +441,7 @@ update.km <- function(object,
           coef.var <- NULL
         }else{
           if((TheClass == "covTensorProduct") | (TheClass == "covIso")) coef.cov <- covparam2vect(object@covariance)
-          if((TheClass == "covAffineScaling") | (TheClass == "covScaling")) coef.cov <- object@covariance@eta
+          if(TheClass == "covScaling") coef.cov <- object@covariance@eta
           
           coef.var <- object@covariance@sd2
         }
@@ -455,16 +456,17 @@ update.km <- function(object,
         
         ## if (is.null(kmcontrol$parinit)) kmcontrol$parinit <- covparam2vect(object@covariance) ## retire
         
-        if ((TheClass == "covTensorProduct") | (TheClass == "covIso") | (TheClass =="covAffineScaling") | (TheClass =="covScaling")) {
+        if ((TheClass == "covTensorProduct") | (TheClass == "covIso") | (TheClass =="covScaling")) {
           object <- km(formula = object@trend.formula, design = object@X, response = object@y,
                        covtype = object@covariance@name, 
                        coef.trend = coef.trend, coef.cov = coef.cov, coef.var = coef.var,
                        nugget=nugget,nugget.estim=nugget.estim,
-                       noise.var = object@noise.var, penalty = kmcontrol$penalty,optim.method = kmcontrol$optim.method,
+                       noise.var = object@noise.var, penalty = kmcontrol$penalty,
+		       optim.method = kmcontrol$optim.method, multistart = kmcontrol$multistart,
                        lower = object@lower, upper = object@upper,
                        control = kmcontrol$control,gr = object@gr,
                        iso =     (TheClass == "covIso"),
-                       scaling = (TheClass == "covAffineScaling" | TheClass == "covScaling"), 
+                       scaling = (TheClass == "covScaling"),
                        knots = knots)                
         } else {
           print("Unknown covariance type. Accepted types are \"covTensorProduct\", \"covIso\" and \"covScaling\"")
